summaryrefslogtreecommitdiff
path: root/include/member.h
diff options
context:
space:
mode:
authorMartijn Otto <martijn.otto@copernica.com>2014-02-17 16:20:09 +0100
committerMartijn Otto <martijn.otto@copernica.com>2014-02-17 16:20:09 +0100
commitca595b1d7aa8ed4a482b8a5ea598ecc1a2636083 (patch)
tree3095d2df9968dbeec6400a192287d42d3312b54d /include/member.h
parent0d910d2ea41c93ccdc2a4d41cec57864504dbc6f (diff)
Some code cleanup
Diffstat (limited to 'include/member.h')
-rw-r--r--include/member.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/include/member.h b/include/member.h
index 347555a..564b1b6 100644
--- a/include/member.h
+++ b/include/member.h
@@ -31,89 +31,89 @@ public:
/**
* Constructor
* @param name Name of the member
- * @param flags Flag access to a class member (bublic, protected etc)
+ * @param flags Flag access to a class member (public, protected etc)
*/
- Member(const char *name, const FlagMemb &&flags);
+ Member(const char *name, MemberModifier flags);
/**
* Constructor
* @param name Name of the member
- * @param flags Flag access to a class member (bublic, protected etc)
+ * @param flags Flag access to a class member (public, protected etc)
* @param value The value to add
*/
- Member(const char *name, const FlagMemb &&flags, std::nullptr_t value);
+ Member(const char *name, MemberModifier flags, std::nullptr_t value);
/**
* Constructor
* @param name Name of the member
- * @param flags Flag access to a class member (bublic, protected etc)
+ * @param flags Flag access to a class member (public, protected etc)
* @param value The value to add
*/
- Member(const char *name, const FlagMemb &&flags, int value);
+ Member(const char *name, MemberModifier flags, int value);
/**
* Constructor
* @param name Name of the member
- * @param flags Flag access to a class member (bublic, protected etc)
+ * @param flags Flag access to a class member (public, protected etc)
* @param value The value to add
*/
- Member(const char *name, const FlagMemb &&flags, long value);
+ Member(const char *name, MemberModifier flags, long value);
/**
* Constructor
* @param name Name of the member
- * @param flags Flag access to a class member (bublic, protected etc)
+ * @param flags Flag access to a class member (public, protected etc)
* @param value The value to add
*/
- Member(const char *name, const FlagMemb &&flags, bool value);
+ Member(const char *name, MemberModifier flags, bool value);
/**
* Constructor
* @param name Name of the member
- * @param flags Flag access to a class member (bublic, protected etc)
+ * @param flags Flag access to a class member (public, protected etc)
* @param value The value to add
*/
- Member(const char *name, const FlagMemb &&flags, char value);
+ Member(const char *name, MemberModifier flags, char value);
/**
* Constructor
* @param name Name of the member
- * @param flags Flag access to a class member (bublic, protected etc)
+ * @param flags Flag access to a class member (public, protected etc)
* @param value The value to add
*/
- Member(const char *name, const FlagMemb &&flags, const std::string &value);
+ Member(const char *name, MemberModifier flags, const std::string &value);
/**
* Constructor
* @param name Name of the member
- * @param flags Flag access to a class member (bublic, protected etc)
+ * @param flags Flag access to a class member (public, protected etc)
* @param value The value to add
* @param size String length
*/
- Member(const char *name, const FlagMemb &&flags, const char *value, int size = -1);
+ Member(const char *name, MemberModifier flags, const char *value, int size = -1);
/**
* Constructor
* @param name Name of the member
- * @param flags Flag access to a class member (bublic, protected etc)
+ * @param flags Flag access to a class member (public, protected etc)
* @param value The value to add
*/
- Member(const char *name, const FlagMemb &&flags, double value);
-
+ Member(const char *name, MemberModifier flags, double value);
+
/**
* Constructor
* @param name Name of the method
- * @param flags Flag access to a class member (bublic, protected etc)
+ * @param flags Flag access to a class member (public, protected etc)
* @param method The method to add
*/
- Member(const char *name, const FlagMemb &&flags, const _Method &method, const std::initializer_list<Argument> &arguments = {});
+ Member(const char *name, MemberModifier flags, const _Method &method, const std::initializer_list<Argument> &arguments = {});
/**
* Copy constructor
* @param member The member to copy
*/
Member(const Member &member);
-
+
/**
* Move constructor
* @param member The member to move
@@ -124,14 +124,14 @@ public:
* Destructor
*/
virtual ~Member();
-
+
/**
* Internal method to declare the property
* @param zend_class_entry
* @internal
*/
void declare(struct _zend_class_entry *entry);
-
+
/**
* Internal method to fill a function entry
* @param zend_function_entry
@@ -139,19 +139,19 @@ public:
* @internal
*/
void fill(struct _zend_function_entry *entry, const char *classname);
-
+
/**
* Is this a property member
* @return bool
*/
bool isProperty();
-
+
/**
* Is this a method member
* @return bool
*/
bool isMethod();
-
+
private:
/**
@@ -159,13 +159,13 @@ private:
* @var string
*/
std::string _name;
-
+
/**
* Flag access to a class member (bublic, protected etc)
* @var bool
*/
- FlagMemb _accflag;
-
+ MemberModifier _flags;
+
/**
* The implementation for the member
* @var MemberInfo
@@ -174,7 +174,7 @@ private:
};
-
+
/**
* End of namespace
*/
@@ -159,13 +159,13 @@ private:
/**
- * Flag access to a class member (bublic, protected etc)
- * @var bool
+ * Flag access to a class member (public, protected etc)
+ * @var MemberModifier
*/